@@ -160,7 +160,7 @@ URL_GHUGENT_HPCUGENT = 'https://github.ugent.be/hpcugent/%(name)s'
 
 RELOAD_VSC_MODS = False
 
-VERSION = '0.15.14'
+VERSION = '0.16.0'
 
 log.info('This is (based on) vsc.install.shared_setup %s' % VERSION)
 log.info('(using setuptools version %s located at %s)' % (setuptools.__version__, setuptools.__file__))
@@ -371,7 +371,7 @@ class vsc_setup(object):
             ],
             'url': [
                 r'^Home-page:\s*(.*?)\s*$',
-                r'^\s*url\s*=\s*((?:https?|ssh).*?github.*?[:/](?:hpcugent|sisc-hpc)/.*?)\.git\s*$',
+                r'^\s*url\s*=\s*((?:https?|ssh).*?github.*?[:/](?:hpcugent|sisc-hpc)/.*?)(?:\.git)?\s*$',
                 r'^\s*url\s*=\s*(git[:@].*?github.*?[:/](?:hpcugent|sisc-hpc)/.*?)(?:\.git)?\s*$',
             ],
             'download_url': [
@@ -658,7 +658,7 @@ class vsc_setup(object):
                 pyshebang_reg = re.compile(r'\A%s.*$' % SHEBANG_ENV_PYTHON, re.M)
                 for fn in scripts:
                     # includes newline
-                    first_line = _read(os.path.join(base_dir, fn), read_lines=True)
+                    first_line = _read(os.path.join(base_dir, fn), read_lines=True)[0]
                     if pyshebang_reg.search(first_line):
                         log.info("going to adapt shebang for script %s" % fn)
                         dest, code = self._recopy(base_dir, fn)
@@ -1461,6 +1461,8 @@ class vsc_setup(object):
             tests_requires.append('prospector >= 1.1.6.4, < 1.3')
             # mock 4.x is no longer compatible with Python 2
             tests_requires.append('mock < 4.0')
+            # isort 5.0 is no longer compatible with Python 2
+            tests_requires.append('isort < 5.0')
         else:
             tests_requires.extend([
                 'prospector',
